JENKINS_FOLDER_CLASS = 'com.cloudbees.hudson.plugins.folder.Folder'

JENKINS_JOB_DISABLED_COLOR = 'disabled'
JENKINS_JOB_RED_COLOR = 'red'

STAND = 'STAND'
